@@ -15,6 +15,3 @@
 
 let personal_dict_file = 
   Filename.concat (Sys.getenv "HOME") ".manadic"
-
-let personal_dict_lock = 
-  Filename.concat (Sys.getenv "HOME") ".manadic_lock"
