@@ -38,7 +38,7 @@ let scm_best_path args =
     let pos = ScmTypes.exact_int_of_datum (ScmTypes.caddr args) in
     let len = ScmTypes.exact_int_of_datum (ScmTypes.cadddr args) in
     let parse_obj = Parse.parse string ~state ~pos ~len in
-    let path = Parse.best_path parse_obj in
+    let path = Parse.best_path_from ~state ~pos parse_obj in
     scm_path path
   with Not_found -> ScmTypes.Nil
 
