@@ -13,7 +13,7 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: parse.mli 144 2005-08-21 12:32:00Z yori $ *)
+(* $Id: parse.mli 150 2005-09-26 08:52:41Z yori $ *)
 
 (** ʸĹʸΰ֤EUCʸοɽ롣*)
 
@@ -24,21 +24,19 @@ type parse_obj
 [pos]Ĺ[len]ʬʸϤѡ롣*)
 val parse : string -> state:int -> pos:int -> len:int -> parse_obj
 
-(** [best_path parse_obj pos][parse_obj][pos]ˤΡɤΤʤ
-ǺŬʥΡɤؤΥѥȺǽ֤ȥȤȤ֤ѥ[(mrph, p,
-l, state, cost)]ΥꥹȤȤɽ졢[p]ʸΰ֡[l]б
-ʬʸĹ[state][mrph]Ϣܤľξ֡[cost]
-[mrph]ޤ᤿[mrph]ޤǤȡѥʤ㳰[Not_found]
-ȯ*)
-val best_path : parse_obj -> 
+(** [best_path_from parse_obj state pos]ϰ[pos][state]
+ Ŭѥ֤*)
+val best_path_from : parse_obj -> state:int -> pos:int ->
   (Chasen.mrph * int * int * int * int) list
 
 (** [list_candidates string state pos mrph_len len][state]ȯ
-[string][pos]Ĺ[mrph_len]ʬʸбǤ󤹤롣
-ͤϷ,Ǥб븶ʸĹ,ηǤ
-ʸκŬȤ[(mrph, state, cost)]ΥꥹȤǤ롣*)
-val list_candidates : string ->
-  state:int -> pos:int -> mrph_len:int -> len:int -> 
+[string][pos]Ĺ[mrph_len]ʬʸбǤ
+롣ͤϷ,Ǥб븶ʸĹ,ηǤ
+Ȥ[(mrph, state, cost)]ΥꥹȤǤ롣*) 
+val list_candidates : string -> state:int -> pos:int -> mrph_len:int -> len:int -> (Chasen.mrph * int * int) list
+
+(** [list_candidates_from parse_obj state pos mrph_len]
+[list_candidates]Ʊͤ[parse_obj]Ѵ롣 *)
+val list_candidates_from : parse_obj -> state:int -> pos:int -> mrph_len:int ->
   (Chasen.mrph * int * int) list
 
-
