@@ -13,34 +13,18 @@
 (*  General Public License for more details.                              *)
 (**************************************************************************)
 
-(* $Id: personalDict.ml 132 2005-08-07 18:05:59Z yori $ *)
-
-let get_lock () =
-  let lock_file = 
-    let flags = [Unix.O_WRONLY; Unix.O_CREAT] in
-    Unix.openfile Config.personal_dict_lock flags 0o600 in
-  Unix.lockf lock_file Unix.F_LOCK 0;
-  lock_file
-
-let release_lock lock_file =
-  Unix.lockf lock_file Unix.F_ULOCK 0;
-  Unix.close lock_file
+(* $Id: personalDict.ml 158 2005-11-21 18:16:30Z yori $ *)
 
 let db = 
-  if not (Sys.file_exists Config.personal_dict_file) then begin
-    let file = 
-      Dbm.opendbm Config.personal_dict_file [Dbm.Dbm_create] 0o600 in
-    Dbm.close file
-  end;
-  let flags = [Dbm.Dbm_rdonly] in
-  Dbm.opendbm Config.personal_dict_file flags 0o600
+  let flags = [Gdbm.Dbm_create; Gdbm.Dbm_rdwr] in
+    Gdbm.opendbm Config.personal_dict_file flags 0o600
 
 let () =
-  at_exit (fun () -> Dbm.close db)
+  at_exit (fun () -> Gdbm.close db)
 
 let get_entry_list key = 
   try
-    let scanbuf = Scanf.Scanning.from_string (Dbm.find db key) in
+    let scanbuf = Scanf.Scanning.from_string (Gdbm.find db key) in
     let s = Scanf.bscanf scanbuf "1,[%S;" (fun s -> s) in
     let rec scan_loop () =
       try Scanf.bscanf scanbuf "%S;" (fun s -> s :: scan_loop ()) with 
@@ -71,13 +55,7 @@ let add mrph =
   let entry_list = get_entry_list keyword in
   let string = 
     encode_entry_list (Chasen.serialize_mrph mrph :: entry_list) in
-  let lock = get_lock () in
-  let db_wr = 
-    let flags = [Dbm.Dbm_rdwr] in
-    Dbm.opendbm Config.personal_dict_file flags 0o600 in
-  Dbm.replace db_wr keyword string;
-  Dbm.close db_wr;
-  release_lock lock
+  Gdbm.replace db keyword string
   
 let remove mrph =
   let keyword = Chasen.keyword mrph in
@@ -91,18 +69,14 @@ let remove mrph =
 	let mrph' = Chasen.mrph_data_of_mrph mrph' in
 	Chasen.headword mrph' <> Chasen.headword mrph)
       mrph_list in
-  let lock = get_lock () in
-  let db_rw =
-    let flags = [Dbm.Dbm_rdwr] in
-    Dbm.opendbm Config.personal_dict_file flags 0o600 in
   if mrph_list = [] then
-    try Dbm.remove db_rw keyword with Dbm.Dbm_error "dbm_delete" -> ()
+    try Gdbm.remove db keyword with Gdbm.Dbm_error "dbm_delete" -> ()
   else
-    Dbm.replace db_rw keyword 
+    Gdbm.replace db keyword 
       (encode_entry_list 
-	 (List.map Chasen.serialize_mrph mrph_list));
-  Dbm.close db_rw;
-  release_lock lock
+	 (List.map Chasen.serialize_mrph mrph_list))
     
 let add_new_word ~kaki ~yomi =
   List.iter add (Chasen.new_word ~kaki ~yomi)
+
+(* let incr_count mrph =*)
